@@ -7,7 +7,7 @@ import uservoice
 from requests_oauthlib import OAuth1
 from urlparse import parse_qs
 import requests
-execfile('uservoice/version.py')
+version='0.0.19'
 
 class APIError(RuntimeError): pass
 class Unauthorized(APIError): pass
@@ -19,8 +19,8 @@ class Client:
         self.request_token = None
         self.token = oauth_token
         self.secret = oauth_token_secret
-        self.default_headers = { 'Content-Type': 'application/json', 'Accept': 'application/json',  'API-Client': 'uservoice-python-' + __version__ }
-        self.oauth = None
+        self.default_headers = { 'Content-Type': 'application/json', 'Accept': 'application/json',  'API-Client': 'uservoice-python-' + version }
+        oauth_hooks = {}
         if api_secret:
             self.oauth = OAuth1(api_key, api_secret, resource_owner_key=self.token, resource_owner_secret=self.secret, callback_uri=callback)
         self.api_url = "{protocol}://{subdomain_name}.{uservoice_domain}".format(
